
# information storage: base unit = byte

def gb(value):
    return value * 1e9

# time: base unit = nanoseconds

def ms(value):
    return value * 1e6

def us(value):
    return value * 1e3

# network capacity: base unit = bits per second

def mbps(value):
    return value * 1e6

def gbps(value):
    return value * 1e6
